PrincipalKind

Enum PrincipalKind 

#[non_exhaustive]
pub enum PrincipalKind { User, Service, System, }
Discriminator for the kind of actor a Principal represents.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


User

Human or end-user identity (id is a UUID string).



Service

Autonomous service-to-service identity (id is a service name).



System

Platform-level system actor (id is a static name, may be outside any org).